<?php

/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       https://teconce.com/about/
 * @since      1.0.0
 *
 * @package    Fontier
 * @subpackage Fontier/public/partials
 */
?>

<!-- This file should primarily consist of HTML with a little bit of PHP. -->

<?php
     global $post;
     $fontieroptions= get_option( 'fontier_options' );
     $previewtitle = $fontieroptions['fontier_default_text'];
?>
<div class="clearfix">
	<div class="font-settings" data-settings="">
		<div class="text">
			<div id="fontier-font-loading" style="display: none;"><i class="zil zi-settings zi-spin"></i></div>
			<input class="settings-input" type="text" name="text" value="" data-default="<?php echo esc_html_e($previewtitle);?>" placeholder="Type here to preview text...">
		</div>
		<div class="font-settings-size">
			<a href="javascript:void(0)" data-size="24" class="s24">24pt</a>
			<a href="javascript:void(0)" data-size="36" class="s36 active">36pt</a>
			<a href="javascript:void(0)" data-size="48" class="s48">48pt</a>
			<a href="javascript:void(0)" data-size="72" class="s72">72pt</a>
		</div>
	</div>
</div>
<div class="clearfix">
	<div class="fontier-font-preview" style="visibility: visible;">
		<ul class="fontier-list">
			<li>
				<span></span>
				<div class="text-center"><i class="zil zi-settings zi-spin"></i> Loading preview, please wait...</div>
			</li>
		</ul>
	</div>
</div>
<script>
(function( $ ) {
	'use strict';

	var req = true;
	jQuery( window ).load(function() 
	{
	    jQuery(".fontier-font-preview").css('visibility', 'visible');
		var images = jQuery(".fontier-font-preview img");
		for (var i = 0; i < images.length; i++)
		{ 
			var ci = images[i];
			jQuery(ci).width(jQuery(ci).width()/2);
		}
	});
	
	jQuery( document ).ready(function() 
	{
		var default_text = jQuery('.settings-input').data('default');
		var default_size = 36;
		returnTypingPreview(default_text, default_size);
		jQuery(".font-test-waterfall").css('visibility', 'visible');
		
		jQuery('.settings-input').on("keyup paste", throttle(function()
		{
			var text = jQuery(this).val();
			if(text.trim().length > 0) 
			{
				jQuery("#fontier-font-loading").show();
				var size = jQuery(".font-settings-size a.active").data("size");
				returnTypingPreview(text, size);
			} else {
			   text = jQuery('.settings-input').data('default');
			}
		}));
		
		jQuery(".font-settings-size a").click(function(e)
		{
			console.log('trigger');
			e.preventDefault();
			if(!jQuery(this).hasClass("active")) 
			{
				var text = jQuery(".settings-input").val();
				if(text == '')
				
				{
					text = jQuery('.settings-input').data('default');
				}
				var size = jQuery(this).data("size");
				var current = jQuery(".font-settings-size a.active");
				var oldsize = jQuery(current).data("size");
				if(text.trim().length > 0) 
				{
					jQuery("#fontier-font-loading").show();
					returnTypingPreview(text, size);
					} else {
					var images = jQuery(".fontier-font-preview img");
					for (var i = 0; i < images.length; i++) 
					{ 
						var iwidth = jQuery(images[i]).width();
						var newwidth = (size * iwidth) / oldsize;
						jQuery(images[i]).width(newwidth);
					}
				} 
				jQuery(current).removeClass("active");
				jQuery(this).addClass("active");
			}
			
		});
	});
	
	function throttle(f, delay){
		var timer = null;
		return function(){
			var context = this, args = arguments;
			clearTimeout(timer);
			timer = window.setTimeout(function()
			{
				f.apply(context, args);
			},
			delay || 900);
		};
	}
		function returnTypingPreview(text, size) 
	{
		
		var data = {'auth' : '<?php echo wp_create_nonce( '_prevnounce' ); ?>', 'size' : size, 'text' : text, 'pid' : '<?php echo esc_html($id); ?>', "action" : "fontGenrate", "font_loader_field" : jQuery('#font_loader_field').val()};
		jQuery.ajax({
			type	: 'POST',
			url		: '<?php echo admin_url( 'admin-ajax.php' ); ?>',
			dataType: 'json',
			data	: data,
			error	: function(data, transport) 
			{
			},
			success: function(result) 
			{
				if(result.status === 1) 
				{
					var cursor = 0;
					var images = result.images;
					jQuery("#fontier-font-loading").hide();
					var image_html = '';
					for (var i = 0; i < images.length; i++)
					{ 
						var image_link = images[i]['url'];
						var image_name = images[i]['name'];
						if(image_name)
						{
							image_html += '<li><span>'+image_name+'</span> <img src="'+images[i]['url']+'" /></li>';	
						}
					}
					jQuery('.fontier-font-preview ul').html(image_html);
				}else{
					jQuery('.fontier-font-preview ul').html('<li>No preview available.</li>');
					jQuery(".settings-input, .font-settings-size a").attr("disabled","disabled");
					jQuery(".font-settings-size a").off('click');
					jQuery(".font-settings-size a").removeClass('active');
					jQuery('.font-settings').fadeTo(0, 0.5);
				}
				req = true;
			}
		});
	}

})( jQuery );


	
</script>
