<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://teconce.com/about/
 * @since      1.0.0
 *
 * @package    Fontier
 * @subpackage Fontier/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Fontier
 * @subpackage Fontier/public
 * @author     Teconce <hello@teconce.com>
 */
class Fontier_Public
{
    private $fontier_product_type 	= 'download';
    private $fontier_product_taxonomy 	= 'download_category';
    public $errors 	= false;
    public $notices = false;
    public $slug 	= 'font_preview';
    function __construct()
    {
        define( 'FONTIER_PATH', plugin_dir_path( __FILE__ ) );
        $this->layout 	= FONTIER_PATH .'/partials/fontier-public-display.php';
        $this->folder 	= basename(FONTIER_PATH);
        $this->dir 		= plugin_dir_url(__FILE__);
        $this->version 	= '1.0';
        $this->errors 	= false;
        $this->notice 	= false;

        add_action('the_content', array($this, 'fontier_before_post_content'));
        add_action('wp_ajax_fontGenrate', array($this, 'fontier_font_preview_generator'));
        add_action('wp_ajax_nopriv_fontGenrate', array($this, 'fontier_font_preview_generator'));
         add_action('wp_enqueue_scripts', array($this, 'fontier_enqueue_styles'));
        
        require_once(FONTIER_PATH .'/partials/fontier-options.php');
    }


 
 
 
   

    public function fontier_before_post_content($content)
    {
        if ( is_singular( $this->fontier_product_type ) )
        {
            $fontier_layout = $this->layout;
            $id			 	= get_the_ID();
            $font_enable 	= $this->fontier_is_font_enable($id);
            
            if($font_enable)
            {

                ob_start();
                if (file_exists($fontier_layout)) {
                    load_template($fontier_layout);
                }
                
                $fontier_content = ob_get_contents();
                ob_end_clean();
                $content		= $fontier_content.$content;

                /* $font_Files 	= $this->fontierGetFontFiles($id);
                    if(isset($font_Files) && !empty($font_Files))
                    {
                } */
            }
        }
        return $content;
    }

    public function fontier_copy_zip($zip_file, $targetFolder, $id)
    {
        $output = array();
        if(!empty($zip_file))
        {
            $zip 			= new ZipArchive;
            if ($zip->open($zip_file ) === true)
            {
                for($i = 0; $i < $zip->numFiles; $i++)
                {
                    $OnlyFileName = $zip->getNameIndex($i);
                    $FullFileName = $zip->statIndex($i);

                    if (!($FullFileName['name'][strlen($FullFileName['name'])-1] =="/"))
                    {
                        if (preg_match('#\.(ttf)$#i', $OnlyFileName))
                        {
                            $name 			= str_replace(' ', '_', strtolower($FullFileName['name']));
                            $file_loc_name 	= $getDirectory.'/fonts/';
                            $name 			= str_replace(' ', '_', strtolower($FullFileName['name']));
                            $zip->renameName($OnlyFileName,	$name);
                            $zip->extractTo($targetFolder, $name);
                            $zip->renameName($name, $OnlyFileName);
                            $output[] = $targetFolder. DIRECTORY_SEPARATOR .$name;
                        }
                    }
                }
                $zip->close();
            }
        }
        return $output;
    }


    public function fontierCheckFont($path)
    {
        if(file_exists($path))
        {
            $folder = opendir($path);
            $pic_types = array("ttf");
            $index = array();
            while ($file = readdir ($folder))
            {
                $parts = explode(".", $file);
                $ext = strtolower($parts[count($parts) - 1]);
                if(in_array($ext, $pic_types))
                {
                    array_push($index, $path. DIRECTORY_SEPARATOR .$file);
                }
            }
            closedir($folder);
            if(!empty($index))
            {
                $filename = $index;
            } else {
                $filename = array();
            }
        } else {
            $filename = array();
        }
        return $filename;
    }

    public function fontierGetFontFiles($id)
    {
      
        $download_files = get_post_meta( $id, 'edd_download_files', true );
         
        
        $result 		= array();
        if(isset($download_files) && is_array($download_files))
        {
            foreach($download_files as $fi)
            {
                $getAID 	= attachment_url_to_postid($fi['file']);
                $zipfile 	= get_attached_file($getAID);

                $Fetchinfo 		= pathinfo($zipfile);
                $getDirectory  	= $Fetchinfo['dirname'];
                $targetFolder 	= $getDirectory. DIRECTORY_SEPARATOR .'fonts'. DIRECTORY_SEPARATOR .$id;
                if (!file_exists($targetFolder))
                {
                    mkdir($targetFolder, 0777, true);
                    $result  	= $this->fontier_copy_zip($zipfile, $targetFolder, $id);
                }else{
                    $result = $this->fontierCheckFont($targetFolder);
                }
            }
        }
        return $result;
    }

    public function fontier_is_font_enable($id)
    {
        $output = false;
        if($id)
        {
               $fontier_metabox = get_post_meta( get_the_ID(), 'fontier_post_option', true );
            
         $enable_check 	= (! empty( $fontier_metabox['font_preview_enable'] ) ) ? $fontier_metabox['font_preview_enable'] : '';
             $this->options = get_option( 'fontier_option_name' );
             $fontieroptions = get_option( 'fontier_options' );
              $cat_id = $fontieroptions['select_font_category'];
               $title = $fontieroptions['fontier_title'];
            $terms = get_the_terms( $id, $this->fontier_product_taxonomy );
            
            if ( $enable_check && ! is_wp_error( $enable_check ) )
            {
                  echo '<div class="fontier-font-preview-pallate">';
                        if($title){
                        echo '<h5 class="fontier-font-title">'.esc_html($title).'<h5>';
                        }

              $output = true;


            }
             
            if ( $terms && ! is_wp_error( $terms ) )
            {
               
                foreach ( $terms as $term )
                {
                  
                    $term_id = $term->term_id;
                    if($term_id == $cat_id)
                    {
                        echo '<div class="fontier-font-preview-pallate">';
                        if($title){
                        echo '<h5 class="fontier-font-title">'.esc_html($title).'<h5>';
                        }
                        $output = true;
                        echo '</div>';
                        break;
                    }
                }
            }
        }
        return $output;
    }

    public function fontierCalculateTextBox($text,$fontFile,$fontSize,$fontAngle)
    {
        /************
        simple function that calculates the *exact* bounding box (single pixel precision).
        The function returns an associative array with these keys:
        left, top:  coordinates you will pass to imagettftext
        width, height: dimension of the image you have to create
         *************/
        $rect = imagettfbbox($fontSize,$fontAngle,$fontFile,$text);
        $minX = min(array($rect[0],$rect[2],$rect[4],$rect[6]));
        $maxX = max(array($rect[0],$rect[2],$rect[4],$rect[6]));
        $minY = min(array($rect[1],$rect[3],$rect[5],$rect[7]));
        $maxY = max(array($rect[1],$rect[3],$rect[5],$rect[7]));

        return array(
            "left"   => abs($minX) - 1,
            "top"    => abs($minY) - 1,
            "width"  => $maxX - $minX,
            "height" => $maxY - $minY,
            "box"    => $rect
        );
    }



    public function fontier_font_preview_generator()
    {
        $retArr = array('status' => 0, 'msg' => '', 'images' => array());
        $nonce 	= sanitize_text_field($_REQUEST['auth']);
        if(wp_verify_nonce( $nonce, '_prevnounce' ))
        {
            $size 	= sanitize_text_field($_REQUEST['size']);
            $text 	= sanitize_text_field($_REQUEST['text']);
            $pid 	= sanitize_text_field($_REQUEST['pid']);
            $font_Files 	= $this->fontierGetFontFiles($pid);
            if(isset($font_Files) && !empty($font_Files))
            {
                foreach($font_Files as $f)
                {
                    $filename 						= pathinfo($f, PATHINFO_FILENAME);
                    $filename 						= str_replace('_', ' ', $filename);
                    $url							=	$this->fontier_create_image(500, 200, $text, $size, $f);
                    $retArr['images'][] 		 	= array('name' => ucwords($filename), 'url' => $url);
                    $retArr['status'] 				= 1;
                    $retArr['msg'] 	  				= 'successfully';
                }

            }else{
                $retArr['msg'] 	  			= 'Font Files are not found';
            }

        }else{
            $retArr['msg'] 	  			= 'Auth Failed!';
        }
        wp_send_json( $retArr );
        wp_die();
    }

    public function fontier_create_image($width, $height, $text, $fontsize, $font_file)
    {
        ob_start ();

        $the_box        = $this->fontierCalculateTextBox($text, $font_file, $fontsize, 0);
        $imageWidth    	= $the_box["width"] + 10;
        $imageHeight    = $the_box["height"] + 10;
        if($imageWidth > 900){
            $imageWidth = 900;
            $x = 0;
            $y = $the_box["top"] + ($imageHeight / 2) - ($the_box["height"] / 2);
        }else{
            $x = $the_box["left"] + ($imageWidth / 2) - ($the_box["width"] / 2);
            $y = $the_box["top"] + ($imageHeight / 2) - ($the_box["height"] / 2);
        }

        $logoimg 		= imagecreatetruecolor($imageWidth, $imageHeight);
        imagealphablending($logoimg, false);
        imagesavealpha($logoimg, true);
        $col		= imagecolorallocatealpha($logoimg,255,255,255,127);
        imagefill($logoimg, 0, 0, $col); //for transparent background
        $black 		= imagecolorallocate($logoimg, 0, 0, 0); //for font color
        $font 		= $font_file; //font path
        $text		= $text; //your text which you want to show in image
        //$x			= 50; // x- position of your text
        //$y			= 50; // y- position of your text
        $angle		= 0; //angle of your text


        imagettftext($logoimg,
            $fontsize,
            $angle,
            $x,
            $y,
            $black,
            $font,
            $text);

        imagepng($logoimg);
        $image_data = ob_get_contents();
        ob_end_clean();
        ImageDestroy($logoimg);//Free memory
        return "data:image/png;base64," . base64_encode( $image_data );
    }

  /**
     * Register all of the hooks related to the public-facing functionality
     * of the plugin.
     *
     * @since    1.0.0
     * @access   private
     */

    public function fontier_enqueue_styles() {
        wp_enqueue_style( 'fontier-public',  plugin_dir_url( __FILE__ ). 'css/fontier-public.css',$this->version, 'all');

    }
    

}
